//--------------------------------------------------------------------------
// 
//  File:       AddonMsgHandler.cpp
//  Part of:    
//  Author:     Tim Philip (me@TimPhilip.net)
//  Compiler:	gcc (under BeOS)
//  Purpose:    
//
//  Notice:     (c) Copyright 2000, Tim Philip
//              All Rights Reserved
//
//  Created:    01/24/00
//
//--------------------------------------------------------------------------

#include <Debug.h>

#include "AddonMsgHandler.h"
#include "ICCMsgs.h"


//--------------------------------------------------------------------------
//	Messages (to BeChess)
//--------------------------------------------------------------------------

// send text to the console and ICC, respectively, AddString("txt", string) for data
const uint32 PLUGINMSG_USERTEXT			= 'PLG0';
const uint32 PLUGINMSG_SERVERTEXT		= 'PLG1';


//--------------------------------------------------------------------------
//	BCAddonMsgHandler :: BCAddonMsgHandler()
//--------------------------------------------------------------------------
BCAddonMsgHandler::BCAddonMsgHandler(const BMessenger *pMsngrBeChess)
	: BLooper()
{
	m_pMsngrBeChess = pMsngrBeChess;

	Run();
	
	//
	// I originally was going to have the add-on tell BeChess which DGs
	// it wanted from ICC, but why bother?  You can just turn them on
	// yourself.  ;)
	//
	
	// Turn on: DG_SEEK, DG_SEEK_REMOVED, DG_NEW_MY_RATING
	BMessage msg(PLUGINMSG_SERVERTEXT);
	msg.AddString("txt", "set-2 50 1\nset-2 51 1\nset-2 87 1\n");
	m_pMsngrBeChess->SendMessage(&msg);

}


//--------------------------------------------------------------------------
//	BCAddonMsgHandler :: MessageReceived()
//--------------------------------------------------------------------------
void BCAddonMsgHandler::MessageReceived(BMessage *pMessage)
{
	//
	// You are in the loop for all messages.  Everything that BeChess
	// pulls from the server will come through your MessageReceived()
	// function.  Catch the DGs that interest you.
	//
	// BeChess is only set up to parse some DGs.  If you ask for a 
	// DG that BeChess isn't familiar with it will get jammed into
	// a message with the following information:
	//
	// const uint32 TELNET_RECEIVE			= 'TEL3';
	// message.AddInt8("dg_type", dg);
    // message.AddString("telnet_text", cpOutBuf);
    //
    // It is very easy for me to add parsing of new DGs into BeChess,
    // just let me know which ones you want.
    //

	switch ( pMessage->what )
	{
		case DGMSG_SEEK:
			{
				// detach the msg, the IccMsg class will clean it up later
				iccMsgParser_SEEK msgParser( DetachCurrentMessage() );
	
				// sample message, echo back to user
				char cpBuf[256];
				sprintf(cpBuf, "%s %s %s %s %s %s %s %s %s %s %s %s %s %s\n",
					msgParser.GetIndex(),
					msgParser.GetName(),
					msgParser.GetTitles(),
					msgParser.GetRating(),
					msgParser.GetWild(),
					msgParser.GetRatingType(),
					msgParser.GetTime(),
					msgParser.GetInc(),
					msgParser.GetRated(),
					msgParser.GetColor(),
					msgParser.GetMinRating(),
					msgParser.GetMaxRating(),
					msgParser.GetAutoAccept(),
					msgParser.GetFormula()
				);
				BMessage msg(PLUGINMSG_USERTEXT);
				msg.AddString("txt", cpBuf);
				m_pMsngrBeChess->SendMessage(&msg);
			}
			break;
		
		case DGMSG_SEEK_REMOVED:
			{
				iccMsgParser_SEEK_REMOVED msgParser( DetachCurrentMessage() );

				// sample message to server (yes, this is a lame example)
				char cpBuf[256];
				sprintf(cpBuf, "tell Kestrel You missed game[%s] because: %s\n", 
					msgParser.GetIndex(),
					msgParser.GetReasonCode()
				);
				BMessage msg(PLUGINMSG_SERVERTEXT);
				msg.AddString("txt", cpBuf);
				m_pMsngrBeChess->SendMessage(&msg);
			}
			break;
		
		case DGMSG_NEW_MY_RATING:
			{
				iccMsgParser_NEW_MY_RATING msgParser( DetachCurrentMessage() );

				// sample message to user
				char cpBuf[256];
				sprintf(cpBuf, "Ratings changed: %s, %s, %s\n", 
					msgParser.GetRating(0),
					msgParser.GetRating(1),
					msgParser.GetRating(2)
				);
				BMessage msg(PLUGINMSG_USERTEXT);
				msg.AddString("txt", cpBuf);
				m_pMsngrBeChess->SendMessage(&msg);
			}
			break;

		default:
			BLooper::MessageReceived(pMessage);
	};
}


