//--------------------------------------------------------------------------
// 
//  File:       ICCMsgs.h
//  Part of:    
//  Author:     Tim Philip (me@TimPhilip.net)
//  Compiler:	gcc (under BeOS)
//  Purpose:    
//
//  Notice:     (c) Copyright 2000, Tim Philip
//              All Rights Reserved
//
//  Created:    02/04/00
//
//--------------------------------------------------------------------------

#ifndef _ICCMSGS_H_
#define _ICCMSGS_H_

#include <Message.h>

#include <string>

//--------------------------------------------------------------------------
//	Messages
//--------------------------------------------------------------------------

const uint32 DGMSG_MY_GAME_STARTED		= 'DG01';
const uint32 DGMSG_MOVE_LIST			= 'DG02';
const uint32 DGMSG_SEND_MOVES			= 'DG03';
const uint32 DGMSG_ILLEGAL_MOVE			= 'DG04';
const uint32 DGMSG_MSEC					= 'DG05';
const uint32 DGMSG_COLOUR				= 'DG06';
const uint32 DGMSG_SEEK					= 'DG07';
const uint32 DGMSG_SEEK_REMOVED			= 'DG08';
const uint32 DGMSG_NEW_MY_RATING		= 'DG09';


//--------------------------------------------------------------------------
//	iccMsgParser
//--------------------------------------------------------------------------
class iccMsgParser
{
public:

	iccMsgParser(BMessage *pMessage) {	m_pMessage = pMessage;	}
	virtual ~iccMsgParser()	{ if ( m_pMessage != NULL )	delete m_pMessage;	}
	
protected:

	const char *GetString(const char *cpName) const;
	const char *GetString(const char *cpName, const int i) const;

	BMessage *m_pMessage;

};


//--------------------------------------------------------------------------
//	DG_SEEK
//--------------------------------------------------------------------------
class iccMsgParser_SEEK : public iccMsgParser
{
	// index name titles rating wild rating-type time inc rated color minrating maxrating autoaccept formula 
	
public:

	iccMsgParser_SEEK(BMessage *pMessage) : iccMsgParser(pMessage)	{}

	// getters
	const char *GetIndex() 		const		{	return GetString("index");			}
	const char *GetName() 		const		{	return GetString("name");			}
	const char *GetTitles() 	const		{	return GetString("titles");			}
	const char *GetRating() 	const		{	return GetString("rating");			}
	const char *GetWild() 		const		{	return GetString("wild");			}
	const char *GetRatingType() const		{	return GetString("ratingtype");		}
	const char *GetTime() 		const		{	return GetString("time");			}
	const char *GetInc() 		const		{	return GetString("inc");			}
	const char *GetRated() 		const		{	return GetString("rated");			}
	const char *GetColor() 		const		{	return GetString("color");			}
	const char *GetMinRating() 	const		{	return GetString("minrating");		}
	const char *GetMaxRating() 	const		{	return GetString("maxrating");		}
	const char *GetAutoAccept() const		{	return GetString("autoaccept");		}
	const char *GetFormula()	const		{	return GetString("formula");		}

};


//--------------------------------------------------------------------------
//	DG_SEEK_REMOVED
//--------------------------------------------------------------------------
class iccMsgParser_SEEK_REMOVED : public iccMsgParser
{
	// index name titles rating wild rating-type time inc rated color minrating maxrating autoaccept formula 
	
public:

	iccMsgParser_SEEK_REMOVED(BMessage *pMessage) : iccMsgParser(pMessage)	{}

	// getters
	const char *GetIndex() 		const		{	return GetString("index");			}
	const char *GetReasonCode()	const		{	return GetString("reasoncode");		}

};


//--------------------------------------------------------------------------
//	DG_NEW_MY_RATING
//--------------------------------------------------------------------------
class iccMsgParser_NEW_MY_RATING : public iccMsgParser
{
	// rating-0 rating-1 rating-2 ...
	
public:

	iccMsgParser_NEW_MY_RATING(BMessage *pMessage) : iccMsgParser(pMessage)	{}

	// getters
	const char *GetRating(const int i) const	{	return GetString("rating", i);	}

};

#endif // _ICCMSGS_H_

